//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// LessonType class - encapsulation of the notion of a lesson type
//
import java.util.Hashtable;

/**
 * LessonType class gives an enumerated typedef of Lesson types.
 */
public class LessonType {

	// only available definitions
	public final static LessonType	TUTORIAL
					= new LessonType( "TUTORIAL" );
	public final static LessonType	DRILL
					= new LessonType( "DRILL" );
	public final static LessonType	PARAGRAPH
					= new LessonType( "PARAGRAPH" );

	// a table to map state names to values in properties-based layouts
	private static Hashtable	types_by_name = new Hashtable();

	// a static block to populate the name table
	static {
		types_by_name.put( "TUTORIAL", TUTORIAL );
		types_by_name.put( "DRILL", DRILL );
		types_by_name.put( "PARAGRAPH", PARAGRAPH );
	}

	// string id representing the lesson type
	private String id;

	/**
	 * Create a new LessonType.
	 */
	private LessonType( String id ) {
		this.id = id;
	}

	/**
	 * Find a LessonType from its logical name.
	 */
	public static LessonType find_lessontype( String name ) {
		return ( (LessonType)(types_by_name.get( name )));
	}

	/**
	 * Return a string representation of the LessonType.
	 */
	public String toString()	{ return ( id ); }

	/**
	 * Return true if this lesson is an exercise.
	 */
	public boolean is_exercise(){
		return ( this == DRILL || this == PARAGRAPH );
	}
}
